#!/bin/bash

function stop_all_services()
{
	supervisorctl stop all
}

function wait_for_obuspa()
{
	local num=0

	echo "wait for bbfdm"
	ubus wait_for bbfdm

	while [ $num -lt 20 ]; do
		obuspa -c get Device.DeviceInfo.SerialNumber > /dev/null 2>&1
		if [ $? -eq 0 ]; then
			echo "Obuspa bootup time = $(( num * 2)) sec"
			return 0;
		fi
		sleep 2
		num=$(( num + 1 ))
	done

	return 255
}

function exec_cmd()
{
	echo "executing $@"
	$@ >/dev/null 2>&1

	if [ $? -ne 0 ]; then
		echo "Failed to execute $@"
		echo "$0 exit status ${ret}"
		stop_all_services
		exit 1
	fi
}

function check_ret()
{
	ret=$?
	if [ $ret -ne 0 ]; then
		stop_all_services
		echo "$0 exit status ${ret}"
		exit $ret
	fi
}

function restart_server()
{
	# install stomp plugin
	if [ "${1}" = "stomp" ]; then
		if [ "${2}" = "enable" ]; then
			rabbitmq-plugins enable rabbitmq_stomp
		else
			rabbitmq-plugins disable rabbitmq_stomp
		fi
	fi
	/etc/init.d/rabbitmq-server restart
	sleep 1
}

function install_obuspa()
{
	COV_CFLAGS='-g -O0 -fprofile-arcs -ftest-coverage'
	COV_LDFLAGS='--coverage'

	make clean >/dev/null 2>&1

	# compile obuspa
	autoreconf --install --force >/dev/null 2>&1
	./configure CFLAGS="$COV_CFLAGS" LDFLAGS="$COV_LDFLAGS" --localstatedir="/tmp" >/dev/null 2>&1
	make

	# install
	make install
	exec_cmd ln -sf ${PWD}/obuspa /usr/sbin/obuspa
}

function install_bbfd()
{
	[ -d "/opt/dev/bbfdm" ] && rm -rf /opt/dev/bbfdm

	if [ -n "${BBFDM_BRANCH}" ]; then
		exec_cmd git clone -b ${BBFDM_BRANCH} https://dev.iopsys.eu/bbf/bbfdm.git /opt/dev/bbfdm
	else
		exec_cmd git clone https://dev.iopsys.eu/bbf/bbfdm.git /opt/dev/bbfdm
	fi

	cd /opt/dev/bbfdm
	./gitlab-ci/install-dependencies.sh install
	./gitlab-ci/setup.sh install
}
